==> simulatorAPMS_1.8.0.tar.gz: simulatorAPMS/man/simulatorS.Rd <==
\name{simulatorS}
\alias{simulatorS}

\title{Function that calculates the FP sticky errors}
\description{
  The simulatorS function is the function that operates on sticky
  baits. It takes in a vector of sticky baits, and for each bait B, it
  finds all the proteins not interacting with it in the ISI. When it has
  calculated this set of proteins, it calls the applyStickyErrors
  function and gets the subset of proteins as the FP hits. It changes
  these interactions from 0 to 1 in the PPCM matrix creating an directed graph PPCM matrix with error.

}
\usage{
simulatorS(sticky, rateS, exMat)
}

\arguments{
  \item{sticky}{A vector of baits known to be sticky}
  \item{rateS}{A single rate of a vector of rates which the experiment
    will record FP's due to the sticky proteins}
  \item{exMat}{The experimental matrix that carries the FP/FN }
}
\details{
  One interesting aspect of this function is that the rateS can either be
  a vector of the same length as the vector of sticky baits, or it can
  be a single rate which is applied to all the sticky baits. The function calls applyStickyErrors on the prescribed sticky baits to assign FP observations onto them. This FP rate is different than the general rateFP and is determined by rateS
}
\value{
  The return value of this function is the adjusted PPCM matrix with error to reflect the
  FP's that have been induced by applyStickyErrors
}

\author{Tony Chiang}




\seealso{\code{\link{simulatorS}}}
\examples{

library(apComplex)
data(MBMEcHMSPCI)
data(HMSPCI)
vBaits = rownames(HMSPCI)[1:10]
PPI = MBMEcHMSPCI %*% t(MBMEcHMSPCI)
mode(PPI) = "logical"
mode(PPI) = "numeric"
exMat = PPI[vBaits,]
stickyBaits = vBaits[2:3]
rateS = 0.9
test = simulatorS(stickyBaits, rateS, MBMEcHMSPCI, exMat) 
test[2:3,]


}
\keyword{misc}

==> simulatorAPMS_1.22.0.tar.gz: simulatorAPMS/man/simulatorS.Rd <==
\name{simulatorS}
\alias{simulatorS}

\title{Function that calculates the FP sticky errors}
\description{
  The simulatorS function is the function that operates on sticky
  baits. It takes in a vector of sticky baits, and for each bait B, it
  finds all the proteins not interacting with it in the ISI. When it has
  calculated this set of proteins, it calls the applyStickyErrors
  function and gets the subset of proteins as the FP hits. It changes
  these interactions from 0 to 1 in the PPCM matrix creating an directed graph PPCM matrix with error.

}
\usage{
simulatorS(sticky, rateS, exMat)
}

\arguments{
  \item{sticky}{A vector of baits known to be sticky}
  \item{rateS}{A single rate of a vector of rates which the experiment
    will record FP's due to the sticky proteins}
  \item{exMat}{The experimental matrix that carries the FP/FN }
}
\details{
  One interesting aspect of this function is that the rateS can either be
  a vector of the same length as the vector of sticky baits, or it can
  be a single rate which is applied to all the sticky baits. The function calls applyStickyErrors on the prescribed sticky baits to assign FP observations onto them. This FP rate is different than the general rateFP and is determined by rateS
}
\value{
  The return value of this function is the adjusted PPCM matrix with error to reflect the
  FP's that have been induced by applyStickyErrors
}

\author{Tony Chiang}




\seealso{\code{\link{simulatorS}}}
\examples{
data(MBMEcHMSPCI)
data(HMSPCI)
vBaits = rownames(MBMEcHMSPCI)[1:10]
PPI = MBMEcHMSPCI %*% t(MBMEcHMSPCI)
mode(PPI) = "logical"
mode(PPI) = "numeric"
exMat = PPI[vBaits,]
stickyBaits = vBaits[2:3]
rateS = 0.9
#test = simulatorS(stickyBaits, rateS, exMat) 
#test[2:3,]


}
\keyword{misc}
